@@ -195,7 +195,7 @@ void TopLevel::setupPartSelection(PartSelection* ps)
  * sub widgets.
  *
  * No positions are saved. These is done automatically for
- * KToolbar, and manually in queryExit() for QT docks.
+ * KToolbar, and manually in queryClose() for Qt docks.
  */
 void TopLevel::saveCurrentState(const QString& postfix)
 {
@@ -1881,11 +1881,6 @@ bool TopLevel::queryClose()
 {
   saveTraceSettings();
 
-  return true;
-}
-
-bool TopLevel::queryExit()
-{
     // save current toplevel options as defaults...
     GlobalConfig::setShowPercentage(_showPercentage);
     GlobalConfig::setShowExpanded(_showExpanded);
@@ -1893,7 +1888,7 @@ bool TopLevel::queryExit()
     GlobalConfig::setHideTemplates(_hideTemplates);
     GlobalGUIConfig::config()->saveOptions();
 
-    saveCurrentState(QString::null);	//krazy:exclude=nullstrassign for old broken gcc
+    saveCurrentState(QString());
 
   // toolbar and dock positions are automatically stored
 
